@@ -30,6 +30,8 @@
 
 #include "clutter-deprecated.h"
 
+#include "clutter-config.h"
+
 #include "clutter-action.h"
 #include "clutter-actor.h"
 #include "clutter-actor-meta.h"
@@ -57,6 +59,7 @@
 #include "clutter-click-action.h"
 #include "clutter-clone.h"
 #include "clutter-color.h"
+#include "clutter-color-static.h"
 #include "clutter-colorize-effect.h"
 #include "clutter-constraint.h"
 #include "clutter-container.h"
@@ -82,6 +85,7 @@
 #include "clutter-model.h"
 #include "clutter-offscreen-effect.h"
 #include "clutter-page-turn-effect.h"
+#include "clutter-path-constraint.h"
 #include "clutter-path.h"
 #include "clutter-rectangle.h"
 #include "clutter-score.h"
@@ -91,10 +95,12 @@
 #include "clutter-shader.h"
 #include "clutter-shader-effect.h"
 #include "clutter-shader-types.h"
+#include "clutter-snap-constraint.h"
 #include "clutter-stage.h"
 #include "clutter-stage-manager.h"
 #include "clutter-stage-window.h"
 #include "clutter-state.h"
+#include "clutter-table-layout.h"
 #include "clutter-texture.h"
 #include "clutter-text.h"
 #include "clutter-timeline.h"
