@@ -36,7 +36,6 @@
 #include "clutter-debug.h"
 #include "clutter-private.h"
 #include "clutter-stage-private.h"
-#include "clutter-version.h"
 
 #include "cogl/cogl.h"
 
@@ -478,29 +477,6 @@ clutter_backend_win32_ensure_context (ClutterBackend *backend,
     }
 }
 
-static void
-clutter_backend_win32_redraw (ClutterBackend *backend,
-			      ClutterStage   *stage)
-{
-  ClutterStageWin32  *stage_win32;
-  ClutterStageWindow *impl;
-
-  impl = _clutter_stage_get_window (stage);
-  if (impl == NULL)
-    return;
-
-  g_return_if_fail (CLUTTER_IS_STAGE_WIN32 (impl));
-
-  stage_win32 = CLUTTER_STAGE_WIN32 (impl);
-
-  /* this will cause the stage implementation to be painted */
-  _clutter_stage_do_paint (stage, NULL);
-  cogl_flush ();
-
-  if (stage_win32->client_dc)
-    SwapBuffers (stage_win32->client_dc);
-}
-
 static ClutterStageWindow *
 clutter_backend_win32_create_stage (ClutterBackend  *backend,
 				    ClutterStage    *wrapper,
@@ -510,9 +486,6 @@ clutter_backend_win32_create_stage (ClutterBackend  *backend,
   ClutterStageWin32 *stage_win32;
   ClutterStageWindow *stage;
 
-  CLUTTER_NOTE (BACKEND, "Creating stage of type '%s'",
-		g_type_name (CLUTTER_STAGE_TYPE));
-
   stage = g_object_new (CLUTTER_TYPE_STAGE_WIN32, NULL);
 
   /* copy backend data into the stage */
@@ -577,7 +550,6 @@ clutter_backend_win32_class_init (ClutterBackendWin32Class *klass)
   backend_class->create_stage     = clutter_backend_win32_create_stage;
   backend_class->add_options      = clutter_backend_win32_add_options;
   backend_class->get_features     = clutter_backend_win32_get_features;
-  backend_class->redraw           = clutter_backend_win32_redraw;
   backend_class->create_context   = clutter_backend_win32_create_context;
   backend_class->ensure_context   = clutter_backend_win32_ensure_context;
   backend_class->get_device_manager = clutter_backend_win32_get_device_manager;
