@@ -308,7 +308,8 @@ test_shader_main (gint argc, gchar *argv[])
   GError        *error;
   gchar         *file;
 
-  clutter_init (&argc, &argv);
+  if (clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+    return 1;
 
   stage = clutter_stage_new ();
   clutter_stage_set_title (CLUTTER_STAGE (stage), "Shaders");
